from setuptools import setup, find_packages

setup(
    name='question_extractor',
    version='0.2.2',
    license='MIT',
    author='Maisa',
    packages=find_packages('src'),
    package_dir={'':'src'},
    url='',
    keywords= 'question_extractor',
    install_requires=[
        'cleantext',
        'visualise-spacy-tree',
        'sentence-transformers',
        'spacy',

    ],

)


import train_predict_extract_question
model_name = "nltk_question_statement_df_model_RBF_SVM_6-17-0"
model_filepath = f"models/{model_name}.sav"
model = train_predict_extract_question.classification_model(mode="predict")
model.predict_init(model_filepath)
sentence = "many ppl do this but, what is your name?"
sentence = train_predict_extract_question.extract_question(str(sentence), model, only_direct=True)

print(sentence)
